#region Bulgarian Educational Site Timetabler - An application for school and university course timetabling
//
// Author:
//   Daniel Denev (mailto:daniel_i_denev@abv.bg)
//
// Copyright (c) 2007 Daniel Denev, VT, Bulgaria
//
// http://best-bg.eu
//
//This file is part of Bulgarian Educational Site Timetabler.
//
//Bulgarian Educational Site Timetabler is free software;
//you can redistribute it and/or modify it under the terms of the GNU General Public License
//as published by the Free Software Foundation; either version 2 of the License,
//or (at your option) any later version.
//
//Bulgarian Educational Site Timetabler is distributed in the hope that it will be useful,
//but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
//or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
//You should have received a copy of the GNU General Public License along with
//Bulgarian Educational Site Timetabler; if not, write to the Free Software Foundation, Inc., 51 Franklin St,


#endregion


using System;
using System.Windows.Forms;
using System.Collections;

namespace BdNTT
{
	/// <summary>
	/// Summary description for AddDayCmd.
	/// </summary>
	public class AddDaysCmd:AbstractCommand
	{
		private ArrayList _toAddList;
		private TreeNode _workingNode;
		private int _tabIndex;
		private bool _calledFromMainForm;

		public AddDaysCmd(ArrayList toAddList)
		{
			_toAddList=toAddList;

			_tabIndex=AppForm.getAppForm().getTreeTabControl().SelectedIndex;

			_calledFromMainForm=false;
			

			if(_tabIndex==0)
			{
				_workingNode=AppForm.getAppForm().getCoursesTreeView().SelectedNode;
			}
			else if(_tabIndex==1)
			{
				_workingNode=AppForm.getAppForm().getTeachersTreeView().SelectedNode;
			}
			else if(_tabIndex==2)
			{
				_workingNode=AppForm.getAppForm().getRoomsTreeView().SelectedNode;
			}
		}


		public AddDaysCmd(ArrayList toAddList, bool calledFromMainForm):this(toAddList)
		{			
			_calledFromMainForm=calledFromMainForm;			
		}

		public override void doit()
		{
			foreach(int n in _toAddList)
			{
				AppForm.CURR_KNOWLEDGE_DOC.setIsDayIncluded(n,true);
				int dayIndexInModel=AppForm.CURR_KNOWLEDGE_DOC.getDayIndexInModel(n);
				ModelOperations.addDayInModel(dayIndexInModel);
			}

			AppForm.getAppForm().refreshGUIAfterDaysTermsChange(true);

		}

		public override void undo()
		{			
			foreach(int n in _toAddList)
			{				
				int dayIndexInModel=AppForm.CURR_KNOWLEDGE_DOC.getDayIndexInModel(n);
				ArrayList [] urLists;
				ModelOperations.delDayInModel(dayIndexInModel, out urLists);
				AppForm.CURR_KNOWLEDGE_DOC.setIsDayIncluded(n,false);
			}
			
			AppForm.getAppForm().getTreeTabControl().SelectedIndexChanged -=new System.EventHandler(AppForm.getAppForm().treeTabControl_SelectedIndexChanged);
			AppForm.getAppForm().getTreeTabControl().SelectedIndex=_tabIndex;
			AppForm.getAppForm().getTreeTabControl().SelectedIndexChanged +=new System.EventHandler(AppForm.getAppForm().treeTabControl_SelectedIndexChanged);

			//AppForm.getAppForm().refreshGUIAfterDaysTermsChange(false);
			AppForm.getAppForm().refreshGUIAfterDaysTermsChange(_calledFromMainForm);

									
			if(_tabIndex==0)
			{
				AppForm.CURR_KNOWLEDGE_DOC.CTVSelectedNode=_workingNode;
				AppForm.getAppForm().ctvRefreshTimetablePanel(_workingNode,true,true);
			
				AppForm.getAppForm().getCoursesTreeView().AfterSelect -= new System.Windows.Forms.TreeViewEventHandler(AppForm.getAppForm().coursesTreeView_AfterSelect);
				AppForm.getAppForm().getCoursesTreeView().SelectedNode=_workingNode;
				AppForm.getAppForm().getCoursesTreeView().AfterSelect += new System.Windows.Forms.TreeViewEventHandler(AppForm.getAppForm().coursesTreeView_AfterSelect);
			}
			else if(_tabIndex==1)
			{			
			
				AppForm.getAppForm().getTeachersTreeView().AfterSelect -= new System.Windows.Forms.TreeViewEventHandler(AppForm.getAppForm().teachersTreeView_AfterSelect);
				AppForm.getAppForm().getTeachersTreeView().SelectedNode=_workingNode;
				AppForm.getAppForm().getTeachersTreeView().AfterSelect += new System.Windows.Forms.TreeViewEventHandler(AppForm.getAppForm().teachersTreeView_AfterSelect);

				AppForm.CURR_KNOWLEDGE_DOC.TTVSelectedNode=_workingNode;
				AppForm.getAppForm().ttvRefreshTimetablePanel(_workingNode,true);
			
			}
			else if(_tabIndex==2)
			{				
				AppForm.getAppForm().getRoomsTreeView().AfterSelect -= new System.Windows.Forms.TreeViewEventHandler(AppForm.getAppForm().roomsTreeView_AfterSelect);
				AppForm.getAppForm().getRoomsTreeView().SelectedNode=_workingNode;
				AppForm.getAppForm().getRoomsTreeView().AfterSelect += new System.Windows.Forms.TreeViewEventHandler(AppForm.getAppForm().roomsTreeView_AfterSelect);

				AppForm.CURR_KNOWLEDGE_DOC.RTVSelectedNode=_workingNode;
				AppForm.getAppForm().rtvRefreshTimetablePanel(_workingNode,true);
			}
		
		}

		public override void redo()
		{
			foreach(int n in _toAddList)
			{
				AppForm.CURR_KNOWLEDGE_DOC.setIsDayIncluded(n,true);
				int dayIndexInModel=AppForm.CURR_KNOWLEDGE_DOC.getDayIndexInModel(n);
				ModelOperations.addDayInModel(dayIndexInModel);
			}

			AppForm.getAppForm().getTreeTabControl().SelectedIndexChanged -=new System.EventHandler(AppForm.getAppForm().treeTabControl_SelectedIndexChanged);
			AppForm.getAppForm().getTreeTabControl().SelectedIndex=_tabIndex;
			AppForm.getAppForm().getTreeTabControl().SelectedIndexChanged +=new System.EventHandler(AppForm.getAppForm().treeTabControl_SelectedIndexChanged);
			
			//AppForm.getAppForm().refreshGUIAfterDaysTermsChange(false);
			AppForm.getAppForm().refreshGUIAfterDaysTermsChange(_calledFromMainForm);
						
			if(_tabIndex==0)
			{
				AppForm.CURR_KNOWLEDGE_DOC.CTVSelectedNode=_workingNode;
				AppForm.getAppForm().ctvRefreshTimetablePanel(_workingNode,true,true);
				
				AppForm.getAppForm().getCoursesTreeView().AfterSelect -= new System.Windows.Forms.TreeViewEventHandler(AppForm.getAppForm().coursesTreeView_AfterSelect);
				AppForm.getAppForm().getCoursesTreeView().SelectedNode=_workingNode;
				AppForm.getAppForm().getCoursesTreeView().AfterSelect += new System.Windows.Forms.TreeViewEventHandler(AppForm.getAppForm().coursesTreeView_AfterSelect);
			}
			else if(_tabIndex==1)
			{	
				AppForm.getAppForm().getTeachersTreeView().AfterSelect -= new System.Windows.Forms.TreeViewEventHandler(AppForm.getAppForm().teachersTreeView_AfterSelect);
				AppForm.getAppForm().getTeachersTreeView().SelectedNode=_workingNode;
				AppForm.getAppForm().getTeachersTreeView().AfterSelect += new System.Windows.Forms.TreeViewEventHandler(AppForm.getAppForm().teachersTreeView_AfterSelect);

				AppForm.CURR_KNOWLEDGE_DOC.TTVSelectedNode=_workingNode;
				AppForm.getAppForm().ttvRefreshTimetablePanel(_workingNode,true);
				
			}
			else if(_tabIndex==2)
			{	
				AppForm.getAppForm().getRoomsTreeView().AfterSelect -= new System.Windows.Forms.TreeViewEventHandler(AppForm.getAppForm().roomsTreeView_AfterSelect);
				AppForm.getAppForm().getRoomsTreeView().SelectedNode=_workingNode;
				AppForm.getAppForm().getRoomsTreeView().AfterSelect += new System.Windows.Forms.TreeViewEventHandler(AppForm.getAppForm().roomsTreeView_AfterSelect);

				AppForm.CURR_KNOWLEDGE_DOC.RTVSelectedNode=_workingNode;
				AppForm.getAppForm().rtvRefreshTimetablePanel(_workingNode,true);
			}	
		}
	}
}
