#region Bulgarian Educational Site Timetabler - An application for school and university course timetabling
//
// Author:
//   Daniel Denev (mailto:daniel_i_denev@abv.bg)
//
// Copyright (c) 2007 Daniel Denev, VT, Bulgaria
//
// http://best-bg.eu
//
//This file is part of Bulgarian Educational Site Timetabler.
//
//Bulgarian Educational Site Timetabler is free software;
//you can redistribute it and/or modify it under the terms of the GNU General Public License
//as published by the Free Software Foundation; either version 2 of the License,
//or (at your option) any later version.
//
//Bulgarian Educational Site Timetabler is distributed in the hope that it will be useful,
//but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
//or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
//You should have received a copy of the GNU General Public License along with
//Bulgarian Educational Site Timetabler; if not, write to the Free Software Foundation, Inc., 51 Franklin St,


#endregion


using System;
using System.Collections;

namespace BdNTT
{
	/// <summary>
	/// Summary description for DeleteRoomCmd.
	/// </summary>
	public class DeleteRoomCmd:AbstractCommand
	{
		private Room _room;
		private ArrayList _undoRedoCoursesList;
        private ArrayList _undoRedoTeachersList;

		public DeleteRoomCmd(Room room)
		{
			_room=room;			
			_undoRedoCoursesList= new ArrayList();
			_undoRedoTeachersList= new ArrayList();
		}

		public override void doit()
		{
			_undoRedoCoursesList.Clear();
			_undoRedoTeachersList.Clear();

			AppForm.CURR_KNOWLEDGE_DOC.RoomsRootNode.Nodes.Remove(_room);
			AppForm.getAppForm().getRoomsTreeView().SelectedNode=AppForm.CURR_KNOWLEDGE_DOC.RoomsRootNode;
			AppForm.getAppForm().getRoomsTreeView().SelectedNode.EnsureVisible();
			
			AppForm.getAppForm().getTreeTabControl().SelectedIndex=2;
			
			foreach(EduProgramGroup epg in AppForm.CURR_KNOWLEDGE_DOC.CoursesRootNode.Nodes) 
			{				
				foreach(EduProgram ep in epg.Nodes)
				{
					foreach(Course course in ep.Nodes)
					{
						if(course.getAllowedRoomsList()!=null)
						{
							if(course.getAllowedRoomsList().Contains(_room))
							{
								course.getAllowedRoomsList().Remove(_room);
								_undoRedoCoursesList.Add(course);
							}
						}
					}
				}
			}

			foreach(Teacher teacher in AppForm.CURR_KNOWLEDGE_DOC.TeachersRootNode.Nodes) 
			{
				if(teacher.getAllowedRoomsList()!=null)
				{
					if(teacher.getAllowedRoomsList().Contains(_room))
					{
						teacher.getAllowedRoomsList().Remove(_room);
						_undoRedoTeachersList.Add(teacher);
					}
				}
			}




		}

		public override void undo()
		{
			AppForm.CURR_KNOWLEDGE_DOC.RoomsRootNode.Nodes.Add(_room);
			AppForm.getAppForm().getRoomsTreeView().SelectedNode=_room;
			AppForm.getAppForm().getRoomsTreeView().SelectedNode.EnsureVisible();
			AppForm.CURR_KNOWLEDGE_DOC.RoomsRootNode.Expand();

			foreach(Course course in _undoRedoCoursesList)
			{
				course.getAllowedRoomsList().Add(_room);
			}

			foreach(Teacher teacher in _undoRedoTeachersList)
			{
				teacher.getAllowedRoomsList().Add(_room);
			}   

			AppForm.getAppForm().getTreeTabControl().SelectedIndex=2;
		}

		public override void redo()
		{
			doit();			
		}
	}
}
