#region Bulgarian Educational Site Timetabler - An application for school and university course timetabling
//
// Author:
//   Daniel Denev (mailto:daniel_i_denev@abv.bg)
//
// Copyright (c) 2007 Daniel Denev, VT, Bulgaria
//
// http://best-bg.eu
//
//This file is part of Bulgarian Educational Site Timetabler.
//
//Bulgarian Educational Site Timetabler is free software;
//you can redistribute it and/or modify it under the terms of the GNU General Public License
//as published by the Free Software Foundation; either version 2 of the License,
//or (at your option) any later version.
//
//Bulgarian Educational Site Timetabler is distributed in the hope that it will be useful,
//but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
//or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
//You should have received a copy of the GNU General Public License along with
//Bulgarian Educational Site Timetabler; if not, write to the Free Software Foundation, Inc., 51 Franklin St,


#endregion

using System;
using System.Xml;
using System.Collections;
using System.IO;
using System.Windows.Forms;

namespace BdNTT
{
	/// <summary>
	/// Summary description for Settings.
	/// </summary>
	public class Settings
	{		
		public static string PDF_READER_APPLICATION;

		public static string EXE_DIR_PATH;
		private static string CONFIG_FILE_NAME="knowledgeconfig.xml";
		private static string RECENT_DOCS_FILE_NAME="knowledgedh.xml";

		public static string GUI_LANGUAGE;
		public static int DEFAULT_GUI_TEXT_TYPE;        

		public static int TIME_SLOT_PANEL_WIDTH;
		public static int TIME_SLOT_PANEL_HEIGHT;

		public static int TIME_SLOT_PANEL_FONT_SIZE;		

        public static string EDU_INSTITUTION_NAME_SETT;
		public static string SCHOOL_YEAR_SETT;
		public static string WORKING_DIR_SETT;

		private const string KNOWLEDGECONFIG_TAG="knowledgeconfig";
		private const string VERSION_ATTRIB="version";
		private const string EDU_INSTITUTION_NAME_TAG="edu_institution_name";
		private const string SCHOOL_YEAR_TAG="school_year";
		private const string WORKING_DIR_TAG="working_dir";

		private const string GUI_TS_WIDTH_TAG="gui_ts_width";
		private const string GUI_TS_HEIGHT_TAG="gui_ts_height";
		private const string GUI_TS_FONT_SIZE_TAG="gui_ts_font_size";
		private const string GUI_DEFAULT_TEXT_TYPE_TAG="gui_default_text_type";
		private const string GUI_LANGUAGE_TAG="gui_language";		
		private const string PDF_READER_TAG="pdf_reader_application";

		private const string RD_TAG="recent_docs";
		private const string DOC_TAG="octdocument";
		private const string KEY_TAG="key";
		private const string PATH_TAG="path";

		public static ArrayList RECENT_DOCS_LIST;
                

		static Settings()
		{	
			string fullPath= Application.ExecutablePath;
			int lastFileSeparatorIndex=fullPath.LastIndexOf(@System.IO.Path.DirectorySeparatorChar);
			EXE_DIR_PATH=fullPath.Substring(0,lastFileSeparatorIndex+1);

			WORKING_DIR_SETT="";
		}

		public static void loadSettings()
		{				
	        
			XmlDocument myXmlDocument = new XmlDocument();

			try
			{				
				myXmlDocument.Load(EXE_DIR_PATH+CONFIG_FILE_NAME);

				XmlNodeList elemList = myXmlDocument.GetElementsByTagName(EDU_INSTITUTION_NAME_TAG);
				EDU_INSTITUTION_NAME_SETT=elemList[0].InnerXml;

				elemList = myXmlDocument.GetElementsByTagName(SCHOOL_YEAR_TAG);
				SCHOOL_YEAR_SETT=elemList[0].InnerXml;

				elemList = myXmlDocument.GetElementsByTagName(WORKING_DIR_TAG);
				WORKING_DIR_SETT=elemList[0].InnerXml;		

				elemList = myXmlDocument.GetElementsByTagName(GUI_TS_WIDTH_TAG);
				TIME_SLOT_PANEL_WIDTH=System.Convert.ToInt32(elemList[0].InnerXml);

				elemList = myXmlDocument.GetElementsByTagName(GUI_TS_HEIGHT_TAG);
				TIME_SLOT_PANEL_HEIGHT=System.Convert.ToInt32(elemList[0].InnerXml);

				elemList = myXmlDocument.GetElementsByTagName(GUI_TS_FONT_SIZE_TAG);
				TIME_SLOT_PANEL_FONT_SIZE=System.Convert.ToInt32(elemList[0].InnerXml);

				elemList = myXmlDocument.GetElementsByTagName(GUI_DEFAULT_TEXT_TYPE_TAG);
				DEFAULT_GUI_TEXT_TYPE=System.Convert.ToInt32(elemList[0].InnerXml);

				elemList = myXmlDocument.GetElementsByTagName(GUI_LANGUAGE_TAG);
				GUI_LANGUAGE=elemList[0].InnerXml;
				
				elemList = myXmlDocument.GetElementsByTagName(PDF_READER_TAG);
				PDF_READER_APPLICATION=elemList[0].InnerXml;

			}
			catch
			{

			}
			finally
			{
				if(EDU_INSTITUTION_NAME_SETT==null) EDU_INSTITUTION_NAME_SETT="Educational institution";
				if(SCHOOL_YEAR_SETT==null) SCHOOL_YEAR_SETT="2006/07";

				if(TIME_SLOT_PANEL_WIDTH == 0) TIME_SLOT_PANEL_WIDTH=100;
				if(TIME_SLOT_PANEL_HEIGHT==0) TIME_SLOT_PANEL_HEIGHT=50;
				if(TIME_SLOT_PANEL_FONT_SIZE==0) TIME_SLOT_PANEL_FONT_SIZE=7;

				if(DEFAULT_GUI_TEXT_TYPE==0) DEFAULT_GUI_TEXT_TYPE=2;

				if(GUI_LANGUAGE==null) GUI_LANGUAGE="";
				
				if(PDF_READER_APPLICATION==null) PDF_READER_APPLICATION="";

			}
		}

		public static void saveAppSettings(SettingsForm settForm)
		{			

			Settings.WORKING_DIR_SETT = settForm.WorkingDir;

			XmlDocument myXmlDocument = new XmlDocument();

			try
			{				
				myXmlDocument.AppendChild(myXmlDocument.CreateXmlDeclaration("1.0","UTF-8",null));
				
				myXmlDocument.AppendChild(myXmlDocument.CreateComment(
					"Generated by Bulgarian Educational Site Timetabler"+
					"\nCopyright Daniel Denev - VT, CROATIA"+
					"\ne-mail: daniel_i_denev@abv.bg"+
					"\n"+"\nConfiguration file for Bulgarian Educational Site Timetabler application"+"\n"));
				
				
				XmlElement myRootElement=myXmlDocument.CreateElement(KNOWLEDGECONFIG_TAG);
				myXmlDocument.AppendChild(myRootElement);
				XmlAttribute verAtt= myXmlDocument.CreateAttribute(VERSION_ATTRIB);
				verAtt.Value="0.7.1";
				myRootElement.SetAttributeNode(verAtt);

				XmlElement elem;
				XmlText textNode;
				elem=myXmlDocument.CreateElement(EDU_INSTITUTION_NAME_TAG);
				myRootElement.AppendChild(elem);                				
				textNode= myXmlDocument.CreateTextNode(settForm.EduInstitutionNameText);
				elem.AppendChild(textNode);

				elem=myXmlDocument.CreateElement(SCHOOL_YEAR_TAG);
				myRootElement.AppendChild(elem);
				textNode= myXmlDocument.CreateTextNode(settForm.SchoolYearText);
				elem.AppendChild(textNode);

				elem=myXmlDocument.CreateElement(WORKING_DIR_TAG);
				myRootElement.AppendChild(elem);
				textNode= myXmlDocument.CreateTextNode(settForm.WorkingDir);
				elem.AppendChild(textNode);

				elem=myXmlDocument.CreateElement(GUI_TS_WIDTH_TAG);
				myRootElement.AppendChild(elem);
				textNode= myXmlDocument.CreateTextNode(settForm.TSPanelWidth.ToString());
				elem.AppendChild(textNode);

				elem=myXmlDocument.CreateElement(GUI_TS_HEIGHT_TAG);
				myRootElement.AppendChild(elem);
				textNode= myXmlDocument.CreateTextNode(settForm.TSPanelHeight.ToString());
				elem.AppendChild(textNode);

				elem=myXmlDocument.CreateElement(GUI_TS_FONT_SIZE_TAG);
				myRootElement.AppendChild(elem);
				textNode= myXmlDocument.CreateTextNode(settForm.TSPanelFontSize.ToString());
				elem.AppendChild(textNode);

				elem=myXmlDocument.CreateElement(GUI_DEFAULT_TEXT_TYPE_TAG);
				myRootElement.AppendChild(elem);
				textNode= myXmlDocument.CreateTextNode(settForm.DefaultGUITextType.ToString());
				elem.AppendChild(textNode);

				elem=myXmlDocument.CreateElement(GUI_LANGUAGE_TAG);
				myRootElement.AppendChild(elem);
				textNode= myXmlDocument.CreateTextNode(settForm.GUILanguage);
				elem.AppendChild(textNode);				

				elem=myXmlDocument.CreateElement(PDF_READER_TAG);
				myRootElement.AppendChild(elem);
				textNode= myXmlDocument.CreateTextNode(settForm.PdfReaderApplication);
				elem.AppendChild(textNode);
			}
			catch
			{			
				
			}
			finally
			{
				myXmlDocument.Save(EXE_DIR_PATH+CONFIG_FILE_NAME);
				EDU_INSTITUTION_NAME_SETT=settForm.EduInstitutionNameText;
				SCHOOL_YEAR_SETT=settForm.SchoolYearText;

				TIME_SLOT_PANEL_WIDTH=settForm.TSPanelWidth;
				TIME_SLOT_PANEL_HEIGHT=settForm.TSPanelHeight;
				TIME_SLOT_PANEL_FONT_SIZE=settForm.TSPanelFontSize;

				DEFAULT_GUI_TEXT_TYPE=settForm.DefaultGUITextType;
				GUI_LANGUAGE=settForm.GUILanguage;				
				PDF_READER_APPLICATION=settForm.PdfReaderApplication;
			}

		}



		public static void saveFileHistory()
		{
			XmlDocument myXmlDocument = new XmlDocument();

			try
			{				
				myXmlDocument.AppendChild(myXmlDocument.CreateXmlDeclaration("1.0","UTF-8",null));
				
				myXmlDocument.AppendChild(myXmlDocument.CreateComment(
					"Generated by Bulgarian Educational Site Timetabler"+
					"\nCopyright Daniel Denev - VT, CROATIA"+
					"\ne-mail: daniel_i_denev@abv.bg"+
					"\n"+"\nRecent documents file for Bulgarian Educational Site Timetabler application"+"\n"));
				
				
				XmlElement myRootElement=myXmlDocument.CreateElement(RD_TAG);
				myXmlDocument.AppendChild(myRootElement);
				XmlAttribute verAtt= myXmlDocument.CreateAttribute(VERSION_ATTRIB);
				verAtt.Value="0.7.1";
				myRootElement.SetAttributeNode(verAtt);

				for(int n=0;n<RECENT_DOCS_LIST.Count;n++)
				{

					XmlElement docElem=myXmlDocument.CreateElement(DOC_TAG);
					myRootElement.AppendChild(docElem);                				

					XmlElement elem;
					XmlText textNode;
					elem=myXmlDocument.CreateElement(KEY_TAG);
					docElem.AppendChild(elem);
					string key="File"+(n+1);
					textNode= myXmlDocument.CreateTextNode(key);
					elem.AppendChild(textNode);

					string path = (string)RECENT_DOCS_LIST[n];
					elem=myXmlDocument.CreateElement(PATH_TAG);
					docElem.AppendChild(elem);
					textNode= myXmlDocument.CreateTextNode(@path);
					elem.AppendChild(textNode);
					
				}
						
			}
			catch
			{					
				
			}
			finally
			{
				myXmlDocument.Save(EXE_DIR_PATH+RECENT_DOCS_FILE_NAME);				
			}

		}


		public static void loadFileHistory()
		{
			RECENT_DOCS_LIST= new ArrayList();
			
			XmlDocument myXmlDocument = new XmlDocument();

			try
			{				
				myXmlDocument.Load(EXE_DIR_PATH+RECENT_DOCS_FILE_NAME);

				XmlNodeList docsElemList = myXmlDocument.GetElementsByTagName(DOC_TAG);

				foreach(XmlElement xmlElem in docsElemList)
				{
					XmlNodeList elemList;					
					elemList = xmlElem.GetElementsByTagName(PATH_TAG);
					string path = elemList[0].InnerXml;					

					RECENT_DOCS_LIST.Add(path);

				}

			}
			catch
			{

			}
			finally
			{
				

			}
		}

	}
}
